@@ -22,10 +22,10 @@
 import re
 from itertools import chain
 
-from charamel import Detector
+from weblate_language_data.country_codes import COUNTRIES
+from weblate_language_data.language_codes import LANGUAGES
 
-from ..countries import COUNTRIES
-from ..languages import LANGUAGES
+from ..chardet import detect_charset
 from .result import DiscoveryResult
 
 TOKEN_SPLIT = re.compile(r"([_.-])")
@@ -125,6 +125,9 @@ class BaseDiscovery(object):
                     if pos + 3 <= len(tokens):
                         if self.is_language_code("".join(tokens[pos : pos + 3])):
                             end = pos + 3
+                    # Skip possible language codes in middle of string
+                    if pos != 0 and end != len(tokens) and tokens[end] != ".":
+                        continue
                     return "{}*{}.{}".format(
                         "".join(tokens[:pos]), "".join(tokens[end:]), ext
                     )
@@ -189,8 +192,6 @@ class BaseDiscovery(object):
         for result in self.get_masks():
             if result["filemask"] in discovered:
                 continue
-            if "template" in result and not self.has_storage(result["template"]):
-                continue
             self.fill_in_template(result)
             self.adjust_format(result)
             self.fill_in_new_base(result)
@@ -242,7 +243,6 @@ class MonoTemplateDiscovery(BaseDiscovery):
 
 class EncodingDiscovery(BaseDiscovery):
     encoding_map = {}
-    detector = Detector(min_confidence=0.7)
 
     def adjust_format(self, result):
         encoding = None
@@ -254,8 +254,7 @@ class EncodingDiscovery(BaseDiscovery):
             if not hasattr(path, "open"):
                 continue
             with self.finder.open(path, "rb") as handle:
-                encoding = self.detector.detect(handle.read())
-                if encoding is not None and encoding.value != "ascii":
-                    if encoding.value in self.encoding_map:
-                        result["file_format"] = self.encoding_map[encoding.value]
-                    return
+                encoding = detect_charset(handle.read())
+                if encoding in self.encoding_map:
+                    result["file_format"] = self.encoding_map[encoding]
+                return
